@@ -2,9 +2,9 @@
  * @Author: BuddyCoder
  * @Date: 2021-08-24 14:50:48
  * @LastEditors: BuddyCoder
- * @LastEditTime: 2021-10-25 15:59:35
+ * @LastEditTime: 2022-03-29 11:23:42
  * @Description: 
- * @FilePath: \pgmacro\src\macros\crud_table_impl.rs
+ * @FilePath: /pgmacro/src/macros/crud_table_impl.rs
  * MIT
  */
   //use proc_macro2::Ident;
@@ -126,7 +126,7 @@
  
  fn py_get_name(table_name: &str) -> proc_macro2::TokenStream {
      quote! {
-         fn get_table_name(prefix: &str) -> String {
+         fn get_table_name(prefix: &str,suffix:&str) -> String {
              if prefix == "" {
                  format!("{}",#table_name)
              }else{
@@ -206,8 +206,8 @@
      //=======================================================================================================
      let py_update_quoted = fields.iter().map(|f| f.py_update_column());
      let py_update = quote! {
-             fn update(&self,prefix:&str) -> Result<(String, Vec<&(dyn ToSql + Sync)>, u32), String> {
-                 let table_name = Self::get_table_name(prefix);
+             fn update(&self,prefix:&str,suffix:&str) -> Result<(String, Vec<&(dyn ToSql + Sync)>, u32), String> {
+                 let table_name = Self::get_table_name(prefix,suffix);
                  let mut sql_columns: Vec<String> = Vec::new();
                  // let mut sql_agrs: Vec<String> = Vec::new();
                  let mut agrs: Vec<&(dyn ToSql + Sync)> = Vec::new();
